← Back to team overview

zorba-coders team mailing list archive

[Merge] lp:~zorba-coders/zorba/bug-1210677-html into lp:zorba/html-module

 

Chris Hillery has proposed merging lp:~zorba-coders/zorba/bug-1210677-html into lp:zorba/html-module.

Commit message:
Replace auto_ptr with unique_ptr.

Requested reviews:
  Chris Hillery (ceejatec)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1210677-html/+merge/184930
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1210677-html/+merge/184930
Your team Zorba Coders is subscribed to branch lp:zorba/html-module.
=== modified file 'src/html.xq.src/html.cpp'
--- src/html.xq.src/html.cpp	2013-08-05 15:14:21 +0000
+++ src/html.xq.src/html.cpp	2013-09-11 04:39:29 +0000
@@ -43,7 +43,7 @@
     const StaticContext* aSctxCtx,
     const DynamicContext* aDynCtx) const
 {
-  std::auto_ptr<std::istringstream> iss;
+  std::unique_ptr<std::istringstream> iss;
   std::istream *is;
   String docString;
   Item lStringItem, lOptionsItem;
@@ -59,11 +59,11 @@
   if ( lStringItem.isStreamable() )
   {
     //
     // The "iss" auto_ptr can NOT be used since it will delete the stream that,
     // in this case, is a data member inside another object and not dynamically
     // allocated.
     //
     // We can't replace "iss" with "is" since we still need the auto_ptr for
     // the case when the result is not streamable.
     //
     is = &lStringItem.getStream();
@@ -59,11 +59,11 @@
   {
     //
-    // The "iss" auto_ptr can NOT be used since it will delete the stream that,
+    // The "iss" unique_ptr can NOT be used since it will delete the stream that,
     // in this case, is a data member inside another object and not dynamically
     // allocated.
@@ -59,11 +59,11 @@
     // allocated.
     //
-    // We can't replace "iss" with "is" since we still need the auto_ptr for
+    // We can't replace "iss" with "is" since we still need the unique_ptr for
     // the case when the result is not streamable.
     //


References